==> cspace-api-0.0.4.tgz: package/README.md <==
# cspace-api


[![npm package](https://img.shields.io/npm/v/cspace-api.svg)](https://www.npmjs.com/package/cspace-api)
[![build status](https://travis-ci.org/collectionspace/cspace-api.js.svg?branch=master)](https://travis-ci.org/collectionspace/cspace-api.js)
[![coverage status](https://coveralls.io/repos/github/collectionspace/cspace-api.js/badge.svg?branch=master)](https://coveralls.io/github/collectionspace/cspace-api.js?branch=master)

This library provides a JavaScript API for operating on CollectionSpace resources. It is a low-level wrapper around the CollectionSpace Services [REST API](https://wiki.collectionspace.org/display/collectionspace/Common+Services+REST+API+documentation).

Release 4.5 of the CollectionSpace services API, which is currently under development, is required. This library is not compatible with releases 4.4 and earlier.

## Features

- Supports browsers and Node.js
- [Promise](http://www.html5rocks.com/en/tutorials/es6/promises/) based

## Installation

Using npm:

```
$ npm install cspace-api
```

Using git:

```
$ git clone https://github.com/collectionspace/cspace-api.js.git
$ cd cspace-api.js
$ npm install
```

## Usage

See the [examples](https://github.com/collectionspace/cspace-api.js/tree/master/examples) and [integration tests](https://github.com/collectionspace/cspace-api.js/tree/master/test/integration) for examples of usage.

## About CollectionSpace

[CollectionSpace](http://www.collectionspace.org/) is a free, open-source collections management application for museums, historical societies, natural science collections, and more.

==> cspace-api-1.0.4.tgz: package/README.md <==
# cspace-api


[![npm package](https://img.shields.io/npm/v/cspace-api.svg)](https://www.npmjs.com/package/cspace-api)
[![build status](https://travis-ci.org/collectionspace/cspace-api.js.svg?branch=master)](https://travis-ci.org/collectionspace/cspace-api.js)
[![coverage status](https://coveralls.io/repos/github/collectionspace/cspace-api.js/badge.svg?branch=master)](https://coveralls.io/github/collectionspace/cspace-api.js?branch=master)

This library provides a JavaScript API for operating on CollectionSpace resources. It is a low-level wrapper around the CollectionSpace Services [REST API](https://wiki.collectionspace.org/display/collectionspace/Common+Services+REST+API+documentation).

Release 4.5 of the CollectionSpace services API is required. This library is not compatible with releases 4.4 and earlier.

## Features

- Supports browsers and Node.js
- [Promise](http://www.html5rocks.com/en/tutorials/es6/promises/) based

## Installation

Using npm:

```
$ npm install cspace-api
```

Using git:

```
$ git clone https://github.com/collectionspace/cspace-api.js.git
$ cd cspace-api.js
$ npm install
```

## Usage

See the [examples](https://github.com/collectionspace/cspace-api.js/tree/master/examples) and [integration tests](https://github.com/collectionspace/cspace-api.js/tree/master/test/integration) for examples of usage.

## About CollectionSpace

[CollectionSpace](http://www.collectionspace.org/) is a free, open-source collections management application for museums, historical societies, natural science collections, and more.
